@@ -7,6 +7,8 @@ import socket
 from typing import Tuple, Optional
 import weakref
 
+from urllib3.exceptions import IncompleteRead
+
 from fsspec.spec import AbstractBufferedFile
 from fsspec.utils import infer_storage_options, tokenize, setup_logging as setup_logger
 from fsspec.asyn import AsyncFileSystem, sync, sync_wrapper, FSTimeoutError
@@ -34,7 +36,7 @@ if "S3FS_LOGGING_LEVEL" in os.environ:
 
 
 MANAGED_COPY_THRESHOLD = 5 * 2 ** 30
-S3_RETRYABLE_ERRORS = (socket.timeout,)
+S3_RETRYABLE_ERRORS = (socket.timeout, IncompleteRead)
 
 _VALID_FILE_MODES = {"r", "w", "a", "rb", "wb", "ab"}
 
@@ -262,7 +264,8 @@ class S3FileSystem(AsyncFileSystem):
                 await tb.tb_frame.f_locals["response"]
             except Exception as e:
                 err = e
-        raise translate_boto_error(err)
+        err = translate_boto_error(err)
+        raise err
 
     call_s3 = sync_wrapper(_call_s3)
 
@@ -602,6 +605,11 @@ class S3FileSystem(AsyncFileSystem):
             return files
         return self.dircache[path]
 
+    async def _glob(self, path, **kwargs):
+        if path.startswith("*"):
+            raise ValueError("Cannot traverse all of S3")
+        return await super()._glob(path, **kwargs)
+
     async def _find(self, path, maxdepth=None, withdirs=None, detail=False, prefix=""):
         """List all files below path.
         Like posix ``find`` command without conditions
@@ -1166,7 +1174,10 @@ class S3FileSystem(AsyncFileSystem):
             return False
 
         # This only returns things within the path and NOT the path object itself
-        return bool(await self._lsdir(path))
+        try:
+            return bool(await self._lsdir(path))
+        except FileNotFoundError:
+            return False
 
     isdir = sync_wrapper(_isdir)
 
